@echo off
setlocal enableextensions enabledelayedexpansion

	rem This script was intended to be called twice from the main capture scripts.
	rem It's job is to launch the capture program and wait for it to end and record 
	rem the return code to a status file that pertains to the board number. This
	rem status file can then be read by the calling program and act according to 
	rem the return code.


:CHECKHELP

	(echo.%*|findstr /L /i /c:"/help" /c:"/h" /c:"/?" >nul: 2>&1) && (goto :HELP)

:CHECKHELP_END
goto :SETUP %*

:SETUP

	call "%~dp0AutoCams.setup.bat" "%~dpnx0" "{%~2}"
	call "%~dp0indent_setup.bat"

	!bat_echolog!
	!bat_echolog! =============================================================
	!bat_echolog! [%date% %time%] - Version: !bat_vers! - [!bat_batchfile! %*]
	!bat_echolog! [!bat_batchfile!:SETUP %*]  Please wait...
	!bat_pushecho!
	

	if /i "%~2" equ "" (
		set bat_returncode=90
		!bat_echolog!
		!bat_echolog! .    ERROR - you need to provide the capturedfilesdir and board number
		!bat_echolog!
		goto :HELP
	)

	!bat_echolog!  call "!bat_exedir!\ReadParams.bat"
	               call "!bat_exedir!\ReadParams.bat"
	
	!bat_echolog!  call "!bat_exedir!\ReadConfig.bat"
	               call "!bat_exedir!\ReadConfig.bat"
	
	
	!bat_echolog!  call "!bat_exedir!\ReadParams_capture16.bat"
	               call "!bat_exedir!\ReadParams_capture16.bat"

	set bat_capturedfilesdir=%~1
	set bat_board=%~2
	
	set bat_batchfile=!bat_batchfile!_!bat_board!
	
	set bat_autonomous=autonomous
	

		rem Parse the archivedfilesdir ["d:\cams16\CAMS\CapturedFiles\2014_11_18_01_19_05] 
		rem into:
		rem      bat_retval1=d:\cams16\CAMS\CapturedFiles
		rem      bat_retval2=2014_11_18_01_19_05
		rem 
	call "!bat_exedir!\ParseDir.bat" "!bat_capturedfilesdir!"
	!bat_logexeclog! set bat_captureddatetime=!bat_retval2!
	!bat_logexeclog! set bat_captureddate=!bat_captureddatetime:~0,10!
	REM Can't do this next one because the dir might be EmailFiles or Coincidence dir.
	REM !bat_logexeclog! set bat_capturedtime=!bat_captureddatetime:~11,8!
	!bat_logexeclog! set bat_capturesession=!bat_captureddatetime!

	call "!bat_exedir!\ParseDir.bat" "!bat_retval1!"
	!bat_logexeclog! set bat_startlocation=!bat_retval1!
	!bat_logexeclog! set bat_startdrive=!bat_startlocation:~0,2!

	!bat_logexeclog! set bat_archivedfilesdir=!bat_startlocation!\ArchivedFiles\!bat_captureddatetime!
	

	!bat_logexeclog! set bat_returncode=running
	
	
goto :MAIN %*




:MAIN
!bat_pushecho! [GOTO !bat_batchfile!:MAIN] [%*]

	call :CLEANUP_DETECT_FILES
	
	call :GETDETECTFILE  "bat_detectfile" "!bat_archivedfilesdir!"
	!bat_logexec! set bat_detect
	
	call :SORTDETECT "!bat_detectfile!"

	rem call :AUTOCAL
	
	rem call :APPLYAUTO
	
	!bat_logexec! set bat_
	
	!bat_log! !bat_call! "!bat_exedir!\autocams.bat" "!bat_capturedfilesdir!" "!bat_archivedfilesdir!" !bat_camera! autonomous
	          !bat_call! "!bat_exedir!\autocams.bat" "!bat_capturedfilesdir!" "!bat_archivedfilesdir!" !bat_camera! autonomous

:MAIN_END
!bat_popecho! [END-!bat_batchfile!:MAIN] - goto :DONE
!bat_echolog!
goto :DONE








Rem ===========================================================================================
Rem                     :CLEANUP_DETECT_FILES
Rem ===========================================================================================
Rem   Clean up the left-over temporary detect files used by the background detect processes
Rem ===========================================================================================

:CLEANUP_DETECT_FILES
!bat_pushecho! [CALL !bat_batchfile!:CLEANUP_DETECT_FILES] [%*]


	set bat_returncode=0

	if not exist "!bat_archivedfilesdir!\FTPdetectinfo_0???.txt" (
		!bat_logexeclog! set bat_returncode=1
		!bat_log! `    OK - not found: "!bat_archivedfilesdir!\FTPdetectinfo_0???.txt"
rem		goto CLEANUP_DETECT_FILES_END
	)

	!bat_push!
	for /f "usebackq tokens=*" %%a in (`dir "!bat_archivedfilesdir!\FTPdetectinfo_0???.txt" /b /a-d /on`) do (
		!bat_echolog!
		!bat_echolog! Renaming "!bat_archivedfilesdir!\%%a"  "!bat_archivedfilesdir!\xxx%%a" 
		!bat_logexec! move /y "!bat_archivedfilesdir!\%%a"  "!bat_archivedfilesdir!\xxx%%a" 
	)
	!bat_pop!

	if exist "!bat_capturedfilesdir!\GCFC.log" (
		!bat_echolog! Deleting "!bat_capturedfilesdir!\GCFC.log" file
		!bat_logexeclog! del /q "!bat_capturedfilesdir!\GCFC.log"
	)
	
	!bat_echolog!
	!bat_echolog!
	!bat_echolog! [!bat_batchfile!:CLEANUP_DETECT_FILES]
	!bat_echolog! Making sure that all the FF*.bin files in the ArchivedFiles dir are also in the CapturedFiles dir
	!bat_echolog! so that autocal and other utilities have them available.
	!bat_echolog! 
	!bat_echolog! This could take several minutes, so please wait...
	
	set bat_tempfile=
	for /f "usebackq tokens=*" %%a in (`dir "!bat_archivedfilesdir!\*.bin" /a-d /on /b`) do (
		set bat_tempfile=%%a
	)
	
	if defined bat_tempfile (
		if not exist "!bat_capturedfilesdir!\!bat_tempfile!" (
			copy /y "!bat_archivedfilesdir!\*.bin" "!bat_capturedfilesdir!"
		)
	)

:CLEANUP_DETECT_FILES_END
!bat_popecho! [RETURN !bat_batchfile!:CLEANUP_DETECT_FILES] [bat_returncode=!bat_returncode!]
!bat_echolog!
exit /b !bat_returncode!









	rem Calls the GetDetectFile.bat script, passing along the two arguments passed.
	rem [out] The first parameter is used as the target variable where the discovered
	rem       detect file in the source dir [specified in the 2nd argument] is stored.
	rem [in]  The source directory.  Typically, either bat_archivedfilesdir
	rem       or bat_confirmedfilesdir.  Could also be directories in the
	rem       SubmissionFiles dir.
:GETDETECTFILE [out] "bat_detectfile" [in] "!bat_archivedfilesdir!"
!bat_pushecho! [CALL !bat_batchfile!:GETDETECTFILE] %*

	if "%~2" equ "" (
		set bat_returncode=1
		!bat_echolog! `    ERROR 1 - detect dir not specified [%~2].
		goto :GETDETECTFILE_END
	)
	
	if not exist "%~2" (
		set bat_returncode=2
		!bat_echolog! `    ERROR 2 - no detect dir not found [%~2].
		goto :GETDETECTFILE_END
	)

	!bat_echolog! !BAT_CALL! "!bat_exedir!\GetDetectFile.bat" "%~1" "%~2"
	              !BAT_CALL! "!bat_exedir!\GetDetectFile.bat" "%~1" "%~2"

	if "!%~1!" equ "" (
		set bat_returncode=3
		!bat_echolog! `    ERROR 3 - Unable to locate detect file [%~1].
		goto :GETDETECTFILE_END
	) else (
		call :GETDETECTFILE_PARSE "!%~1!"
	)

	if not exist "!%~1!" (
		set bat_returncode=4
		!bat_echolog! `    ERROR 4 - Unable to locate detect file [!%~1!].
		goto :GETDETECTFILE_END
	)

:GETDETECTFILE_END
!bat_popecho! [RETURN !bat_batchfile!:GETDETECTFILE] [%~1=!%~1!]
!bat_echolog!
!bat_return!





	rem Take the specified detect fiel and produce four variables out of it as follows:
	rem   bat_detectfile1    full detectfile name
	rem   bat_detectfile3    Just the filename w/o extent
	rem   bat_detectfile4    The filename w/ extent
:GETDETECTFILE_PARSE [in] "!bat_detectfile!"
!bat_pushlog! [CALL !bat_batchfile!:GETDETECTFILE_PARSE] %*
	set bat_detectfile1=%~1
	set bat_detectfile3=%~n1
	set bat_detectfile4=%~nx1
!bat_poplog! [RETURN !bat_batchfile!:GETDETECTFILE_PARSE] [bat_detectfile1=!bat_detectfile1!, 
!bat_log! `                                        bat_detectfile3=!bat_detectfile3!,
!bat_log! `                                        bat_detectfile4=!bat_detectfile4!]
!bat_log!
!bat_return!





:SORTDETECT [IN] "!bat_detectfile!"
!bat_pushecho! [CALL !bat_batchfile!:SORTDETECT] [%*]

	rem SortDetect by camera
	if /i "!bat_CONFIRMATION.sortbycamera!" equ "true" (
		if "!bat_archivedmeteorcount!" LEQ "!bat_CONFIRMATION.sort.max!" (
		rem if not exist "!bat_archivedfilesdir!\SortDetect_CameraList.txt" (
			!bat_CALL! "!bat_exedir!\SortDetect.bat" "!bat_detectfile!"
			set bat_returncode=!errorlevel!

			if /i "!bat_returncode!" neq "0" (
				set bat_recent_error_msg= '    ERROR [!bat_returncode!] - FAILED: call "!bat_exedir!\SortDetect.bat" "!bat_detectfile!"
				!bat_echolog!
				!bat_echolog! !bat_recent_error_msg!
				!bat_echolog!
				
				!bat_WAIT! 5
				
				goto :CONFIRM2
			)
		rem )
		)
	)

:SORTDETECT_END
!bat_popecho! [RETURN !bat_batchfile!:SORTDETECT] [bat_detectfile=%~1]
!bat_echolog!
!bat_return!




	rem 7b. Cal Auto Update ********************************************
:AUTOCAL
!bat_pushecho! [CALL !bat_batchfile!:AUTOCAL] [%*]

	set bat_returncode=0
	set bat_retval=success


	rem Should be something like:
	rem   call ""autocal.bat" 100 1.00 "!bat_caldir!" "!bat_capturedfilesdir!"
	rem
	rem And then check the autocal log for success/failure

	if not defined bat_capturedfilesdir (
		set bat_returncode=7
		!bat_log! `    ERROR 7 - No CapturedFiles directory defined.
		goto :AUTOCAL_END
	)

	if not defined bat_archivedfilesdir (
		set bat_returncode=1
		!bat_log! `    ERROR 1 - No ArcivedFiles directory defined.
		goto :AUTOCAL_END
	)
	
	if not exist "!bat_archivedfilesdir!" (
		set bat_returncode=2
		!bat_log! `    ERROR 2 - No ArchivedFiles directory found.
		goto :AUTOCAL_END
	)
	
	if not defined bat_detectfile (
		set bat_returncode=3
		!bat_log! `    ERROR 3 - No bat_detectfile defined.
		GOTO :AUTOCAL_END
	)
	
	rem Read the Meteor Count from the detect file and set the bat_archivedmeteorcount variable...
	for /f "usebackq tokens=3" %%a in (`find /i /c ".bin" "!bat_detectfile!"`) do (
		set bat_archivedmeteorcount=%%c
	)

	if /i "!bat_archivedmeteorcount!" equ "-1" (
		!bat_push!
			set bat_returncode=4
			set bat_recent_error_msg=ERROR 4 - 7b. Auto Calibration failed - Meteor Count is 0. Nothing to calibrate.
			!bat_echolog! !bat_recent_error_msg!
			call :SAVECONFIG

			set bat_retval=failed
		!bat_pop!
		goto :AUTOCAL_END
	) else (
		!bat_push!
		
			rem Should be something like:
			rem   call ""autocal.bat" 100 1.00 "!bat_caldir!" "!bat_capturedfilesdir!"
			rem
			rem And then check the autocal log for success/failure

			if not exist "!bat_capturedfilesdir!\GCFC.log" (
				call "!bat_exedir!\CreateCameraListFile.bat" "!bat_capturedfilesdir!"
			)


			for /f "usebackq tokens=*" %%a in (`type "!bat_capturedfilesdir!\GCFC.log"^|sort /r`) do (
				set bat_camera_first=%%a
			)


			rem Call AutoCal.bat to perform the autocal procedure.  Returns errorlevel...
			!bat_log! call "!bat_exedir!\AutoCal.bat" "!bat_capturedfilesdir!" "!bat_archivedfilesdir!" !bat_camera_first! !bat_calnstars! !bat_caloc! !bat_autonomous!
			          call "!bat_exedir!\AutoCal.bat" "!bat_capturedfilesdir!" "!bat_archivedfilesdir!" !bat_camera_first! !bat_calnstars! !bat_caloc! !bat_autonomous!
			set bat_returncode=!errorlevel!

			!bat_echolog! Return code from FTP_MeteorCal_AutoUpdate.exe is: !bat_returncode!
			set bat_retval=executed
		!bat_pop!
	)
	
	!bat_echolog!
	!bat_echolog! "^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"
	!bat_echolog!
	
	set bat_calfilelist.created=

	!bat_pushecho! [!bat_batchfile!:AUTOCAL]  Validate the AutoCalUpdate.log file for each camera...
	set bat_camera_temp=
	for /f "usebackq tokens=1-12 skip=2" %%a in (`find /i "camera " "!bat_capturedfilesdir!\AutoCalUpdate.log"`) do (
		set bat_autocal_success=0

		if /i "%%a" neq "Auto-Calibrating" (
			!bat_echolog! %%a %%b %%c %%d, %%e %%f %%g %%h %%i

			if /i "%%a" equ "camera" (
				set bat_autocal_camera=%%b
				set bat_autocal_success=%%c
				set bat_autocal_nstars=%%d
				set bat_autocal_oc=%%e
				set bat_autocal_fffile=%%f
				set bat_autocal_calfile=%%g

				if !bat_autocal_oc! GTR !bat_caloc! (
					set bat_autocal_success=1
					set bat_returncode=11
					set bat_recent_error_msg=ERROR 11 - 7b. Auto Calibration failed - ERROR   O-C !bat_autocal_oc! GTR !bat_caloc!
					call :SAVECONFIG
					!bat_push!
						!bat_echolog!
						!bat_echolog! !bat_recent_error_msg!
						!bat_echolog!
						!bat_echolog! Camera:	!bat_autocal_camera!
						!bat_echolog! Success:	FAILED
						!bat_echolog! nStars:	!bat_autocal_nstars!
						!bat_echolog! O-C:	!bat_autocal_oc!
						!bat_echolog! FF file:	!bat_autocal_fffile!
						!bat_echolog! calfile:	!bat_autocal_calfile!
						!bat_echolog!
					!bat_pop!

					rem Delete the cal file if the O-C value is too high, even though
					rem the .exe program thinks it's ok. 
					if "!bat_autocal_calfile!" neq "" (
						if exist "!bat_caldir!\!bat_autocal_calfile!" (
							if defined bat_caldir (
								if defined bat_autocal_calfile (
									!bat_logexec! del "!bat_caldir!\!bat_autocal_calfile!"
								) else (
									!bat_echolog! ERROR [!bat_batchfile!:CALUPDATEAUTO] Dangerous command: del "!bat_caldir!\!bat_autocal_calfile!" 
								)
							) else (
								!bat_echolog! ERROR [!bat_batchfile!:CALUPDATEAUTO] Dangerous command: del "!bat_caldir!\!bat_autocal_calfile!" 
							)
						)
					)

					!bat_echolog! `    !bat_recent_error_msg!
				)& rem !bat_autocal_oc! GTR !bat_caloc!
	
				if /i "!bat_autocal_success!" neq "0" (
					set bat_returncode=12
					!bat_echolog! `    set bat_returncode=[!bat_returncode!]
					set bat_recent_error_msg=ERROR 12 - 7b.a. Auto Calibration failed
					call :SAVECONFIG
					!bat_echolog! `    !bat_recent_error_msg!
				) else (
					!bat_push!
						!bat_echolog!
						!bat_echolog! Camera:	!bat_autocal_camera!
						!bat_echolog! Success:	SUCCESS
						!bat_echolog! nStars:	!bat_autocal_nstars!
						!bat_echolog! O-C:		!bat_autocal_oc!
						!bat_echolog! FF file:	!bat_autocal_fffile!
						!bat_echolog! calfile:	!bat_autocal_calfile!
						!bat_echolog!
					!bat_pop!
					set bat_recent_error_msg=SUCCESS - 7b. Auto Calibration successful [!bat_autocal_calfile!, !bat_autocal_nstars!, !bat_autocal_oc!]
					call :SAVECONFIG
					!bat_echolog! `    !bat_recent_error_msg!
					
					if not defined bat_calfilelist.created (
						call :CREATECALFILELIST "!bat_detectfile!"
						call :GETMETEORCOUNTARCHIVED bat_archivedmeteorcount "!bat_archivedfilesdir!"
						call "!bat_exedir!\FixDetectPaths.bat" "!bat_archivedfilesdir!" "!bat_detectfile!"
						set bat_calfilelist.create=true
					)

				)
	
				!bat_echolog!
			)
		)
	)
	!bat_popecho! End of validation...
	

:AUTOCAL_END
!bat_popecho! [RETURN !bat_batchfile!:AUTOCAL] [!bat_retval!, !bat_returncode!]
!bat_echolog!
set bat_calfilelist.created=
!bat_return!





	rem 9. Apply cal to detectinfo *******************************
:APPLYAUTO
!bat_echolog! [CALL !bat_batchfile!:APPLYAUTO] %*
	set bat_returncode=0
	set bat_retval=failed
	set bat_latestcal=

	if "!bat_archivedmeteorcount!" equ "0" (
		set bat_returncode=1
		!bat_errorlog! `    ERROR 1 - Meteor Count is 0. Nothing to calibrate.
	) else (
		!bat_echolog! !bat_CALL! "!bat_exedir!\ApplyCal.bat" "!bat_archivedfilesdir!" autonomous
				      !bat_CALL! "!bat_exedir!\ApplyCal.bat" "!bat_archivedfilesdir!" autonomous>nul:
		set bat_returncode=!errorlevel!
		!bat_echolog! `    ERRORLEVEL=[!bat_returncode!]
		if !bat_returncode! neq 0 (
			!bat_echolog! `    ERROR ApplyCal.bat failed
			goto :APPLYAUTO_END
		)

	if not exist "!bat_detectfile!" (
		set bat_returncode=3
		!bat_echolog! `    ERROR 3 - Can't find detect file: "!bat_detectfile!"
		goto :APPLYAUTO_END
	)

		echo for /f "usebackq tokens=* skip=2" %%a in ^(`find /i ".txt" "!bat_detectfile!"`^) do ...>>"!bat_logfile!"
		echo for /f "usebackq tokens=* skip=2" %%a in ^(`find /i ".txt" "!bat_detectfile!"`^) do ...
		for      /f "usebackq tokens=* skip=2" %%a in  (`find /i ".txt" "!bat_detectfile!"`) do (
			if not defined bat_latestcal (
				set bat_latestcal=%%a
			)
		)
	)

	!bat_echolog! `    Cal file in "!bat_detectfile!":
	!bat_echolog! `    "!bat_latestcal!"
	if defined bat_latestcal (
		set bat_retval=success
	)
	
:APPLYAUTO_END
!bat_echolog! [RETURN !bat_batchfile!:APPLYAUTO] [!bat_retval!, "!bat_latestcal!"]
!bat_log!
!bat_return!







:GETMETEORCOUNTARCHIVED [in] bat_archivedmeteorcount "!bat_archivedfilesdir!"
!bat_pushlog! [CALL !bat_batchfile!:GETMETEORCOUNTARCHIVED] [%*]
	set bat_returncode=0
	
	set bat_temp=%~1
	!bat_log! argv[1]="%~1"

	if /i "!bat_temp!" equ "" (
		set bat_returncode=1
		!bat_echolog! `[!bat_batchfile!:GETMETEORCOUNTARCHIVED]    ERROR 1 - bat_archivedfilesdir variable is blank
		goto :GETMETEORCOUNTARCHIVED_END
	)

	set bat_temp=%~2
	!bat_log! bat_argv[2]="%~2"
	if /i "!bat_temp!" equ "" (
		!bat_echolog! `!bat_batchfile!:GETMETEORCOUNTARCHIVED]    ERROR 2 - !bat_batchfile!:GETMETEORCOUNTARCHIVED - 2nd argument is missing.
		goto :GETMETEORCOUNTARCHIVED_END
	)

	set bat_temp=%~2
	set bat_temp2=%~nx2
	if not defined bat_capturedtime (
		if defined bat_capturedfilesdir (
				rem Parse the bat_capturedfilesdir and extract the time segment
			for /f "usebackq tokens=*" %%x in (`echo "!bat_capturedfilesdir!"`) do (
				set bat_temp3=%%~nxx
				set bat_capturedtime=!bat_temp3:~11,8!
			)
		) else (
			set bat_returncode=3
			!bat_echolog! `!bat_batchfile!:GETMETEORCOUNTARCHIVED]    ERROR 3 - !bat_batchfile!:GETMETEORCOUNTARCHIVED - bat_capturedfilesdir isn't defined yet.
			goto :GETMETEORCOUNTARCHIVED_END
		)
	)

	if not defined bat_detectfile (
		set bat_returncode=4
		!bat_echolog! `!bat_batchfile!:GETMETEORCOUNTARCHIVED]    ERROR 4 - Not defined: bat_detectfile, setting to "!bat_detectfile!"
		goto :GETMETEORCOUNTARCHIVED_END
	)

	set %~1=
	set bat_latestcal=

	if /i "%~2" equ "" (
		!bat_echolog! `    WARNING - !bat_batchfile!:GETMETEORCOUNTARCHIVED - No ArchivedFiles directory
		goto :GETMETEORCOUNTARCHIVED_END
	)

	if not defined bat_detectfile (
		call :FINDDETECT "bat_detectfile" "bat_archivedfilesdir"
	)

	
	set /a %~1=0
	rem !bat_log! for /f "usebackq tokens=* skip=2" ..a in ^(`find /i ".txt" "!bat_detectfile!"`^) do ...
	rem for           /f "usebackq tokens=* skip=2" %%a in  (`find /i ".txt" "!bat_detectfile!"`) do (
	!bat_log! for /f "usebackq tokens=1-3 skip=1 delims=:" ..a in ^(`find /i /c ".txt" "!bat_detectfile!"`^) do ...
	for           /f "usebackq tokens=1-3 skip=1 delims=:" %%a in  (`find /i /c ".txt" "!bat_detectfile!"`) do (
		rem set /a %~1+=1
		set bat_temp=%%c
		set bat_temp=!bat_temp:~1,20!
		set /a %~1=!bat_temp!
		set bat_temp=
	)

	call :GETLATESTCAL "!bat_captureddate!"

	!bat_logexeclog! type "!bat_archivedfilesdir!\CalFileList.log"

	!bat_pushlog! Perform ValidateCal.bat for each file in: "!bat_archivedfilesdir!\CalFileList.log"...
	for /f "usebackq tokens=*" %%X in (`type "!bat_archivedfilesdir!\CalFileList.log"`) do (
		set bat_temp=%%X
		if /i "!bat_temp:~3,3!" equ "!bat_camera!" (
			set bat_detectcal=%%X
		)
		
		!bat_echolog! Validating Cal files..."%%X"
		!bat_log! call "!bat_exedir!\ValidateCal.bat" /cal "%%X"
		          call "!bat_exedir!\ValidateCal.bat" /cal "%%X"
		!bat_echolog!
	)
	!bat_pop!
!bat_log! /////////////  bat_latestcal=!bat_latestcal!, bat_detectcal=!bat_detectcal!

:GETMETEORCOUNTARCHIVED_END
!bat_poplog! [RETURN !bat_batchfile!:GETMETEORCOUNTARCHIVED] [bat_archivedmeteorcount=!bat_archivedmeteorcount!, bat_latestcal=!bat_latestcal!, bat_detectcal=!bat_detectcal!]
!bat_log!
!bat_return!







	rem Creates the "CalFileList.log" in the ArchivedFiles dir.  The file
	rem contains a list of all the Cal files found in the detect file
	rem [one for each camera in the detect file]. 
:CREATECALFILELIST
!bat_pushlog! [CALL !bat_batchfile!:CREATECALFILELIST] %*
	!bat_log! call "!bat_exedir!\CreateCalFileList.bat" "!bat_detectfile!"
	          call "!bat_exedir!\CreateCalFileList.bat" "!bat_detectfile!"

:CREATECALFILELIST_END
!bat_poplog! [RETURN !bat_batchfile!:CREATECALFILELIST] [!bat_camera_list!]
!bat_log!
!bat_return!






:READCONFIG
!bat_pushlog! [CALL !bat_batchfile!:READCONFIG] %*
	set bat_retval=failed
	set bat_configfile=!bat_exedir!\AutoCams.bat.ini
	
	!bat_push!
	for /f "usebackq tokens=*" %%x in (`type "!bat_configfile!"`) do (
		set bat_retval=success
		set bat_temp=%%x
							rem if /i "%%x" neq "[CAMSMENU]" (
							rem      set %%x
							rem )

		if /i "!bat_temp!" neq "" (
			if /i "!bat_temp:~0,1!" neq " " (
				if /i "!bat_temp:~0,1!" neq "	" (
					if /i "!bat_temp:~0,2!" neq "//" (
						rem It's not a single-line comment "//"

						if /i "!bat_temp:~0,3!" neq "rem" (
							rem It's not a single line comment "rem"

							if /i "!bat_temp:~0,4!" neq "rem " (
								rem It's not a comment "rem "

								if /i "!bat_temp:~0,1!" equ "[" (
									rem It's a [section]
									set bat_temp=!bat_temp:~1,99!
									set bat_inisection=bat_!bat_temp:~0,-1!
								) else (
									rem It's a bat_key=value
									if "!bat_temp:~0,4!" equ "bat_" (
									rem !bat_log! `    set !bat_temp!
												   set !bat_temp!
									) else (
											rem It's a key=value
											set !bat_inisection!.!bat_temp!
									)
								)
							)
						)
					)
				)
			)
		)
	)
	!bat_pop!

	rem set bat_targetdrive=!bat_targetlocation:~0,2!
	set bat_targetdrive=!bat_targetlocation!

%bat_COMMENT_BEGIN%
	set bat_GCFC_tempfile=!bat_capturedfilesdir!\GCFC.log
	!bat_echolog! call "!bat_exedir!\CreateCameraListFile.bat" "!bat_capturedfilesdir!"
	              call "!bat_exedir!\CreateCameraListFile.bat" "!bat_capturedfilesdir!"

	!bat_log! bat_archivedfilesdir=!bat_archivedfilesdir!bbbbbbbbbbbbbbbb+++++++++++++++++++++++++++++++++++++++++++++++
	call :GETDETECTFILE  "bat_detectfile" "!bat_archivedfilesdir!"
	if defined bat_detectfile (
		if exist "!bat_detectfile!" (
			if not exist "!bat_archivedfilesdir!\CalFileList.log" (
				call :CREATECALFILELIST "!bat_detectfile!"
			)
		)
	)

	call :GETMETEORCOUNTARCHIVED bat_archivedmeteorcount  "!bat_archivedfilesdir!"

	call :GETCONFIRMEDCOUNT bat_confirmedmeteorcount "!bat_confirmedfilesdir!"
%bat_COMMENT_END%

:READCONFIG_END
!bat_poplog! [RETURN !bat_batchfile!:READCONFIG] [AutoCams.bat.ini=!bat_retval!, "!bat_capturedfilesdir!"]
!bat_log!
!bat_return!







	rem 48. Save Configuration ************************************
:SAVECONFIG
!bat_pushlog! [CALL !bat_batchfile!:SAVECONFIG] [%*]
	set bat_configfile=!bat_exedir!\AutoCams.bat.ini

	echo [CAMSMENU]>"!bat_configfile!"
	echo bat_targetlocation=!bat_targetlocation!>>"!bat_configfile!"
	echo bat_camera=!bat_camera!>>"!bat_configfile!"
	echo bat_captureddate=!bat_captureddate!>>"!bat_configfile!"
	echo bat_capturedfilesdir=!bat_capturedfilesdir!>>"!bat_configfile!"
	echo bat_archivedfilesdir=!bat_archivedfilesdir!>>"!bat_configfile!"
	echo bat_capturedcount=!bat_capturedcount!>>"!bat_configfile!"
	echo bat_archivedcount=!bat_archivedcount!>>"!bat_configfile!"
	echo bat_latestcal=!bat_latestcal!>>"!bat_configfile!"
	echo bat_submissionfilesdir=!bat_submissionfilesdir!>>"!bat_configfile!"
	echo bat_ftppassword=!bat_ftppassword!>>"!bat_configfile!"
	echo bat_ftpsite=!bat_ftpsite!>>"!bat_configfile!"
	echo bat_ftpuser=!bat_ftpuser!>>"!bat_configfile!"
	echo bat_ftpdir=!bat_ftpdir!>>"!bat_configfile!"
	echo bat_recent_error_msg=!bat_recent_error_msg!>>"!bat_configfile!"
:SAVECONFIG_END
!bat_poplog! [RETURN !bat_batchfile!:SAVECONFIG] []
!bat_log!
!bat_return!



:HELP
	echo.%~0	Batch Script
	echo.Usage: %~0 "^<bat_capturedfilesdir^>" "^<board number^>"
	echo.
	echo.Performs post-capture processing for a single Capture8 capture session.  This 
	echo.script is called by each Capture8_ReturnCode.bat instance [once for each board]. 
	echo.
	echo.Where:
	echo.   bat_capturedfilesdir        Full path to the capture session under the CapturedFiles dir.
	echo.   board number                The sensoray board 8 channel board number
	echo.
	echo.Example(s):
	echo.
exit /b -99







:DONE
	!bat_popecho! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	!bat_echolog! Done with %0 %*
	!bat_echolog!
	
exit /b !bat_returncode!


