@echo off
setlocal enableextensions enabledelayedexpansion

	rem This script was intended to be called twice from the main capture scripts.
	rem It's job is to launch the capture program and wait for it to end and record 
	rem the return code to a status file that pertains to the board number. This
	rem status file can then be read by the calling program and act according to 
	rem the return code.


:CHECKHELP

	(echo.%*|findstr /L /i /c:"/help" /c:"/h" /c:"/?" >nul: 2>&1) && (goto :HELP)

:CHECKHELP_END
goto :SETUP %*

:SETUP
	call "%~dp0AutoCams.setup.bat" "%~dpnx0" "{%~2}"
	call "%~dp0indent_setup.bat"
	
	set bat_logdir=!bat_exedir!\Logs
	set bat_pushstring=  

	!bat_echolog!
	!bat_echolog! =============================================================
	!bat_echolog! %date% %time% - Version: !bat_vers! - %~dpnx0 [%*]
	!bat_echolog! [!bat_batchfile!_!bat_board!:SETUP %*]  Please wait...
	!bat_pushecho!
	

	if /i "%~1" equ "" (
		set bat_returncode=90
		!bat_echolog!
		!bat_echolog! .    ERROR - You must provide the duration as the first command line argument
		!bat_echolog!
		goto :DONE
	)
	
	
	!bat_CALL! "!bat_exedir!\ReadParams_capture16.bat"

	call :READCONFIG

	set bat_duration=%~1
	set bat_board=%~2
	
	!bat_logexeclog! set bat_batchfile=!bat_batchfile!_!bat_board!
	
	set bat_sensoray_config_file_full=Sensoray812_config_board_!bat_board!.txt
	set bat_archive_mode=2
	set bat_camera_first=!bat_CAPTURE8.first.camera.board%bat_board%!

	set bat_capture8_exe_filename=FTP_Capture8AndDetect_!bat_board!.exe
	set bat_ftp_capture8_!bat_board!=bat_capture8_exe_filename
	set bat_capture8_exe_full=!bat_exedir!\!bat_capture8_exe_filename!
	
	set bat_cmd_Capture8_exe_filename=cmd_Capture8_board_!bat_board!.bat.exe
	set bat_cmd_Capture8_exe_full=!bat_exedir!\!bat_cmd_Capture8_exe_filename!

	set bat_cmd_self=!bat_cmd_Capture8_exe_filename!
	set bat_cmd_process_handle_self=
	set bat_capture8_process_handle_!bat_board!=


	set bat_returncode=running
	
	
title %~nx0 %1 %2 %3 %4 %5 %6 %7 %8

goto :MAIN %*




:MAIN
!bat_pushecho! [GOTO !bat_batchfile!:MAIN] [%*]

	rem Returns !bat_capturesession_precapture!
	call :GET_PRECAPTUREFOLDER
	if /i "!bat_returncode!" neq "0" (goto :MAIN_END)
	
	call :CAPTURE
	if /i "!bat_returncode!" neq "0" (goto :MAIN_END)

	call :GET_POSTCAPTUREFOLDER
	if /i "!bat_returncode!" neq "0" (goto :MAIN_END)

	rem Copy the Capture16.params.ini settings so that we can record what settings were used
	rem for capture.  We do this so that we can troubleshoot dropped frames scenarios.
	!bat_logexec! copy /y "!bat_exedir!\capture16.params.ini" "!bat_capturedfilesdir!"
	!bat_logexec! copy /y "!bat_exedir!\Sensoray812_config_board_!bat_board!.txt" "!bat_capturedfilesdir!"
	!bat_logexec! copy /y "!bat_exedir!\FrameGrabConfig.txt" "!bat_capturedfilesdir!"
	

	call :WAIT_CAPTURE_FINISH
	
		rem Suspend SELF bat_cmd_Capture8_exe_filename [this CMD] until start16cameras resumes me. 
	call :SUSPEND_CMD_SHELL "!bat_cmd_self!"

		rem You won't get here until start16cameras resumes you
	!bat_echolog! !bat_batchfile! Wait 20
	!bat_WAIT! 20

	rem Calling SaveConfig.bat now might not be a good thing to do because it may be mixed
	rem with the SaveConfig.bat of another instance of this script.  I think a better approach
	rem would be to have SaveConfig.bat script output to a different file that is specific 
	rem to this instance of Capture8_ReturnCode.bat.
	call :SAVECONFIG
	
	REM MAYBE WE SHOULD HAVE THIS SUSPEND ITSELF AT THIS POINT TO HAVE START16CAMERAS.BAT
	REM CALL THE POSTCAPTUREPROCESSING SCRIPT FOR EACH BOARD?
	
	!bat_echolog! call "!bat_exedir!\Capture8_PostCaptureProcessing.bat" "!bat_capturedfilesdir!" "!bat_board!" "autonomous"
	              call "!bat_exedir!\Capture8_PostCaptureProcessing.bat" "!bat_capturedfilesdir!" "!bat_board!" "autonomous"

:MAIN_END
!bat_popecho! [END-!bat_batchfile!:MAIN] - goto :DONE
!bat_echolog!
goto :DONE











	Rem ===========================================================================================
	Rem                     :GET_PRECAPTUREFOLDER
	Rem ===========================================================================================
	Rem   Identify the most recently run CapturedFiles subfolder by sorting on folder name (date)
	Rem   from earliest created to most recent.
	Rem ===========================================================================================

:GET_PRECAPTUREFOLDER
!bat_pushecho! [CALL   !bat_batchfile!:GET_PRECAPTUREFOLDER] [%*]

	set bat_returncode=0

	set bat_capturesession_precapture=2000_01_01_00_00_00


	for /f "usebackq tokens=*" %%a in (`dir "!bat_CAMS_capturefolder!\2???_??_??_??_??_??" /ad /s/b /on`) do (
		set bat_capturesession_precapture=%%~na
	)
	
	
	if /i "!bat_capturesession_precapture!" equ "2000_01_01_00_00_00" (
		set bat_returncode=1
		!bat_echolog! .   ###ERROR - No previous directories in the CapturedFiles directory.
	)


:GET_PRECAPTUREFOLDER_END
!bat_popecho! [RETURN !bat_batchfile!:GET_PRECAPTUREFOLDER]   [bat_returncode=!bat_returncode!, Before capture session: "!bat_capturesession_precapture!"]
!bat_echolog!
exit /b !bat_returncode!


	
	Rem ===========================================================================================
	Rem                     :CAPTURE
	Rem ===========================================================================================
	Rem   Launch the capture program
	Rem ===========================================================================================

:CAPTURE
!bat_pushecho! [CALL   !bat_batchfile!:CAPTURE] [%*]

	!bat_echolog! copy /y "!bat_exedir!\FTP_Capture8AndDetect.exe" "!bat_capture8_exe_full!"
	              copy /y "!bat_exedir!\FTP_Capture8AndDetect.exe" "!bat_capture8_exe_full!"

	rem Wait for the calling program to have a chance to set the affinity mask of the command
	rem processor, so that the capture program instance can inherit the affinity mask.
	!bat_echolog! [!bat_batchfile!] Wait long enough to give the calling program a chance to set the affinity mask of this command processor...
	!bat_echolog! !bat_batchfile! Wait 2
	!bat_WAIT!  2 /nobreak

	!bat_echolog!
	!bat_echolog! First, kill the capture program if it is still running from the night before.
	!bat_echolog! We do this especially in case it gets frozen or hung for any reason.  
	!bat_echolog!
	!bat_echolog! call "!bat_exedir!\process.exe" -k "!bat_capture8_exe_full!"
	        !bat_call! "!bat_exedir!\process.exe" -k "!bat_capture8_exe_full!"

	!bat_echolog! start "[%date% %time%] !bat_capture8_exe_full!" "!bat_capture8_exe_full!" "!bat_sensoray_config_file_full!" !bat_archive_mode!  !bat_camera_first!  !bat_numdetectproc%bat_board%! !bat_duration! "!bat_CAMS_directory!"
	              start "[%date% %time%] !bat_capture8_exe_full!" "!bat_capture8_exe_full!" "!bat_sensoray_config_file_full!" !bat_archive_mode!  !bat_camera_first!  !bat_numdetectproc%bat_board%! !bat_duration! "!bat_CAMS_directory!"

	!bat_echolog! !bat_batchfile! Wait 15  [Long enough for the capture program to produce the first set of *.bin files]
	!bat_WAIT!  15 /nobreak

	SET /A bat_affinity_count=0
:CAPTURE_AFFINITY
!bat_echolog! [goto !bat_batchfile!:CAPTURE_AFFINITY] [!bat_affinity_count!]
	SET /A bat_affinity_count=0
	!bat_echolog!
	!bat_echolog! Setting the processor affinity mask for the capture program ...
			process|find /i "!bat_capture8_exe_filename!"
	!bat_echolog! for /f "usebackq tokens=1-3" ..a in ^(`process^|find /i "!bat_capture8_exe_filename!"`^) do ^(
	for               /f "usebackq tokens=1-3" %%a in (`process^|find /i "!bat_capture8_exe_filename!"`) do (
			!bat_logexec! process -a %%b !bat_RUN.processor_affinity_mask!
		SET /A bat_affinity_count+=1
	)

	IF !bat_affinity_count! GTR 100 (goto :CAPTURE_END)
	if !bat_affinity_count! equ 0 (
		!bat_WAIT! 1 /NOBREAK
		goto :CAPTURE_AFFINITY
	)

	!bat_echolog!
	!bat_echolog! Setting the processor affinity mask for the FTP_DetectSingleFF.exe's...
	!bat_echolog! Note: Don't worry if some of these fail.  It it usually because these
	!bat_echolog!       short-lived processes may have ended by the time the loop gets 
	!bat_echolog!       around the the instance. 
			process|find /i "FTP_DetectSingleFF.exe"
	for /f "usebackq tokens=1-3" %%a in (`process^|find /i "FTP_DetectSingleFF.exe"`) do (
			!bat_logexec! process -a %%b !bat_RUN.processor_affinity_mask!
	)
	

	
	set bat_returncode=0

:CAPTURE_END
!bat_popecho! [RETURN !bat_batchfile!:CAPTURE]   [bat_returncode=!bat_returncode!, Before capture session: "!bat_capturesession_precapture!"]
!bat_echolog!
exit /b !bat_returncode!



	Rem ===========================================================================================
	Rem                     :GET_POSTCAPTUREFOLDER
	Rem ===========================================================================================
	Rem   Identify newly generated CapturedFiles subfolder by sorting on folder name (date) from
	Rem   earliest created to most recent.
	Rem
		Rem After 3 seconds, it should have created the folder for the new capture session.  We need to determine
		rem that new capture session folder before the second board's capture session starts...
		rem 
		rem Returns: bat_capturesession
		rem          bat_capturedfilesdir
	Rem ===========================================================================================

:GET_POSTCAPTUREFOLDER
!bat_pushecho! [CALL   !bat_batchfile!:GET_POSTCAPTUREFOLDER] [%*]

	set bat_returncode=1
	set bat_capturesession=2000_01_01_00_00_00

	!bat_echolog!
	!bat_echolog! Identify the newly generated CapturedFiles subfolder by sorting on folder name [date] from
	!bat_echolog! earliest created to the most recent.  Remember, there was a wait employed to allow time
	!bat_echolog! for the newly launched capture program to produce it's new CapturedFiles dir.
	
	!bat_pushlog! for /f "usebackq tokens=*" ..a in ^(`dir "!bat_CAMS_capturefolder!\2???_??_??_??_??_??" /ad /s/b /on`^) do ^(
	              for /f "usebackq tokens=*" %%a in  (`dir "!bat_CAMS_capturefolder!\2???_??_??_??_??_??" /ad /s/b /on`) do (
		!bat_logexec! set bat_capturedfilesdir=%%a
		set bat_capturesession=%%~na
		set bat_capturedatetime=%%~na
		set bat_captureddate=%%~na
		set bat_captureddate=!bat_captureddate:~0,10!
		set bat_capturedtime=!bat_capturesession:~11,8!
		
		set bat_archivedfilesdir=!bat_CAMS_archivefolder!\!bat_capturesession!
		
		!bat_logexec! set bat_returncode=0
	)
	!bat_poplog! ^)

	if "!bat_returncode!" neq "0" (
		!bat_echolog! `   ###ERROR - No New Captured Files Folder ###ERROR
		goto :GET_POSTCAPTUREFOLDER_END
	)
	
	!bat_echolog!
	!bat_echolog! Try to determine the first camera number in this capture session for this board
	!bat_echolog! by scanning for *.bin files in reverse order.  The last one found is the first
	!bat_echolog! camera. 
	!bat_echolog! Note: This loop shouldn't take that long because it's early in the capture session
	set /a bat_capturedcount=0
	!bat_pushlog! for /f "usebackq tokens=*" ..a in ^(`dir "!bat_capturedfilesdir!\*.bin" /o-n /b /a-d`^) do ^(
	for               /f "usebackq tokens=*" %%a in  (`dir "!bat_capturedfilesdir!\*.bin" /o-n /b /a-d`) do (
		set /a bat_capturedcount+=1
		!bat_log! !bat_capturedcount!	============%%a===============

		set bat_temp=%%a
		!bat_logexeclog! set bat_camera=!bat_temp:~2,3!
	)
	!bat_poplog! ^)
	
	!bat_logexeclog! set bat_capture
	
		REM Redirect logs asap so as not to mingle log entries with the one in ..\Logs. 
	!bat_CALL! "!bat_exedir!\RedirectLogs.bat" "!bat_targetlocation!\CAMS\Logs\!bat_capturedatetime!"


:GET_POSTCAPTUREFOLDER_END
!bat_popecho! [RETURN !bat_batchfile!:GET_POSTCAPTUREFOLDER]  [exitcode=!bat_returncode!, Capture session = "!bat_capturesession!",
!bat_echolog! `                                          bat_capturedfilesdir="!bat_capturedfilesdir!",
!bat_echolog! `                                          bat_archivedfilesdir="!bat_archivedfilesdir!",
!bat_echolog! `                                          bat_camera=!bat_camera!,
!bat_echolog! `                                          bat_logdir=!bat_logdir!]
!bat_echolog!
exit /b !bat_returncode!




	Rem ===========================================================================================
	Rem                     :WAIT_CAPTURE_FINISH
	Rem ===========================================================================================
	Rem   Identify newly generated CapturedFiles subfolder by sorting on folder name (date) from
	Rem   earliest created to most recent.
	Rem
		Rem After 3 seconds, it should have created the folder for the new capture session.  We need to determine
		rem that capture session folder before the second board's capture session starts...
		rem 
		rem Returns: bat_capturesession
		rem          bat_capturedfilesdir
	Rem ===========================================================================================

:WAIT_CAPTURE_FINISH
!bat_pushecho! [CALL !bat_batchfile!:WAIT_CAPTURE_FINISH] [%*]
	rem This should wait for the capture session to finish. At which time, we can do some other post-capture processing.
	!bat_echolog!
	!bat_echolog! [!bat_batchfile!] Waiting for "!bat_capture8_exe_full!" to finish.......
	!bat_echolog!
	call WaitForFile rw "!bat_capture8_exe_full!" >nul: 2>&1
	
		Rem Give Start16Cameras a chance to finish writing to the log
	!bat_WAIT! 1 /nobreak
	!bat_echolog! !bat_batchfile! Wait 60
	!bat_wait! 60
	
	!bat_echolog! [!bat_batchfile!:MAIN] -----------------------------------------------------------------
	!bat_echolog! [!bat_batchfile!:MAIN] -----------------------------------------------------------------
	!bat_echolog! [!bat_batchfile!:MAIN] -----------------------------------------------------------------
	!bat_echolog! [!bat_batchfile!:MAIN] [!date! !time!] Capture Finished
	!bat_echolog! [!bat_batchfile!:MAIN] bat_archivedfilesdir=!bat_archivedfilesdir!
	!bat_echolog! [!bat_batchfile!:MAIN] bat_capturesession=!bat_capturesession!
	!bat_echolog!

	set bat_returncode=0
:WAIT_CAPTURE_FINISH_END
!bat_popecho! [RETURN !bat_batchfile!:WAIT_CAPTURE_FINISH]  [exitcode=!bat_returncode!, Capture session = "!bat_capturesession!"
!bat_echolog!
exit /b !bat_returncode!




	REM ****************************************************************
	REM *****       SUSPEND BOARD 1's CMD SHELL                    *****
	REM
	REM Suspends the given command shell so that it doesn't interfere
	REM with BOARD 0's processing.  Also, it could become a problem 
	REM if the logs for the scripts in the two command shells are
	REM being intermingled.
	REM 
	REM Returns:
	REM    bat_RetVal           The process handle that was suspended
	REM ****************************************************************

:SUSPEND_CMD_SHELL [IN] "!bat_cmd_process_handle_self!"
!bat_pushecho! [CALL !bat_batchfile!:SUSPEND_CMD_SHELL] [%*]
	SETLOCAL ENABLEEXTENSIONS ENABLEDELAYEDEXPANSION

	!bat_TITLEWAIT! [SUSPENDED] %~nx0 %*

	!bat_echolog! [!bat_batchfile!] [!DATE! !TIME!] SUSPEND - PID="%~1" - SUSPEND CMD self until start16cameras RESUMES board !bat_board!
	!bat_logexeclog! process -s "%~1"

	rem Give Start16Cameras script a chance to finish writing to the log...
	!bat_WAIT! 1 /nobreak
	!bat_echolog! [!bat_batchfile!] You shouldn't see this until start16cameras RESUMES IT
	!bat_echolog! [!bat_batchfile!] [!DATE! !TIME!] RESUMED - PID="%~1"

	!bat_TITLE!

:SUSPEND_CMD_SHELL_END
!bat_popecho! [RETURN !bat_batchfile!:SUSPEND_CMD_SHELL] [bat_process_handle=!bat_process_handle!]
!bat_echolog!
ENDLOCAL
exit /b %~1
	REM YOU'LL NEVER GET TO HERE...
!BAT_RETURN!




:GET_PROCESS_HANDLE [IN] "^<process name^>"
!bat_pushecho! [CALL !bat_batchfile!:GET_PROCESS_HANDLE] [%*]

	SETLOCAL ENABLEEXTENSIONS ENABLEDELAYEDEXPANSION

	set bat_process_name=%~nx1
	
	set bat_process_handle=-1

		REM find the process handle for the given process's name...
	for /f "usebackq tokens=1-7" %%a in (`process -c ^| find /i "!bat_process_name!"`) do (
		!bat_logexeclog! set bat_process_handle=%%b
	)


:GET_PROCESS_HANDLE_END
!bat_popecho! [RETURN !bat_batchfile!:GET_PROCESS_HANDLE] [bat_process_handle=!bat_process_handle!]
!bat_echolog!
exit /b !bat_process_handle!
ENDLOCAL
!BAT_RETURN!


	Rem ===========================================================================================
	Rem                     :CLEANUP_DETECT_FILES
	Rem ===========================================================================================
	Rem   Clean up the left-over temporary detect files used by the background detect processes
	Rem ===========================================================================================

:CLEANUP_DETECT_FILES
!bat_pushecho! [CALL !bat_batchfile!:CLEANUP_DETECT_FILES] [%*]


	set bat_returncode=0

	if not exist "!bat_archivedfilesdir!\FTPdetectinfo_0???.txt" (
		set bat_returncode=1
		!bat_echolog! .    ###ERROR - not found: "!bat_archivedfilesdir!\FTPdetectinfo_0???.txt"
		goto CLEANUP_DETECT_FILES_END
	)

	for /f "usebackq tokens=*" %%a in (`dir "!bat_archivedfilesdir!\FTPdetectinfo_0???.txt" /b /a-d /on`) do (
		!bat_logexec! move /y "!bat_archivedfilesdir!\%%a"  "!bat_archivedfilesdir!\xxx%%a" 
	)

!bat_echolog!
!bat_echolog! "!bat_archivedfilesdir!"

	for /f "usebackq tokens=*" %%a in (`dir "!bat_archivedfilesdir!\FTPdetectinfo*.txt" /b /a-d /on`) do (
		!bat_echolog! "!bat_archivedfilesdir!\%%a" 
	)


:CLEANUP_DETECT_FILES_END
!bat_popecho! [RETURN !bat_batchfile!:CLEANUP_DETECT_FILES] [bat_returncode=!bat_returncode!]
!bat_echolog!
exit /b !bat_returncode!









	rem Calls the GetDetectFile.bat script, passing along the two arguments passed.
	rem [out] The first parameter is used as the target variable where the discovered
	rem       detect file in the source dir [specified in the 2nd argument] is stored.
	rem [in]  The source directory.  Typically, either bat_archivedfilesdir
	rem       or bat_confirmedfilesdir.  Could also be directories in the
	rem       SubmissionFiles dir.
:GETDETECTFILE [out] "bat_detectfile" [in] "bat_archivedfilesdir"
!bat_pushecho! [CALL !bat_batchfile!:GETDETECTFILE] %*

	call "!bat_exedir!\GetDetectFile.bat" "%~1" "%~2"

	if not defined %~1 (
		!bat_echolog! `    ERROR - Unable to locate detect file [%~1].
		goto :GETDETECTFILE_END
	) else (
		call :GETDETECTFILE_PARSE "!%~1!"
	)

	if not exist "!%~1!" (
		!bat_echolog! `    ERROR - Unable to locate detect file [%~1].
		goto :GETDETECTFILE_END
	)

:GETDETECTFILE_END
!bat_popecho! [RETURN !bat_batchfile!:GETDETECTFILE] [%~1=!%~1!]
!bat_echolog!
!bat_return!





	rem Take the specified detect fiel and produce four variables out of it as follows:
	rem   bat_detectfile1    full detectfile name
	rem   bat_detectfile3    Just the filename w/o extent
	rem   bat_detectfile4    The filename w/ extent
:GETDETECTFILE_PARSE [in] "!bat_detectfile!"
!bat_pushlog! [CALL !bat_batchfile!:GETDETECTFILE_PARSE] %*
	set bat_detectfile1=%~1
	set bat_detectfile3=%~n1
	set bat_detectfile4=%~nx1
!bat_poplog! [RETURN !bat_batchfile!:GETDETECTFILE_PARSE] [!bat_detectfile1!, 
!bat_log! `                                        !bat_detectfile3!,
!bat_log! `                                        !bat_detectfile4!]
!bat_log!
!bat_return!












:READCONFIG
!bat_pushlog! [CALL !bat_batchfile!:READCONFIG] %*
	
	!BAT_CALL! "!bat_exedir!\ReadConfig.bat"
	set bat_submissionfilesdir=
	set bat_capturedcount=
	set bat_archivedcount=
	set bat_latestcal=
	

:READCONFIG_END
!bat_poplog! [RETURN !bat_batchfile!:READCONFIG] [AutoCams.bat.ini=!bat_retval!, "!bat_capturedfilesdir!"]
!bat_log!
!bat_return!







	rem 48. Save Configuration ************************************
:SAVECONFIG
!bat_pushlog! [CALL !bat_batchfile!:SAVECONFIG] [%*]

	!bat_CALL! "!bat_exedir!\SaveConfig.bat"


:SAVECONFIG_END
!bat_poplog! [RETURN !bat_batchfile!:SAVECONFIG] []
!bat_log!
!bat_return!




	We're launching this script asynchronously from it's own personal command shell so that
	when we're done, this script can copy the error code return by capture to a file specific
	to the board.

:HELP
	echo.%~0	Batch Script
	echo.Usage: %~0 ^<duration^> ^<board^>
	echo.
	echo.Where:
	echo.   duration        is either a positive number of hours to record or
	echo.                   a negative number representing the sun angle.  
	echo.                   Specifying a negative number causes the program to
	echo.                   use the absolute value of the sun angle as the number
	echo.                   of degrees below the horizon to start/stop capture.
	echo.
	echo.Example:
	echo.   %~0   0.1          to capture both cameras for 6 minutes.
	echo.   %~0   -8           to capture when between astronomical dusk to dawn.
	echo.
exit /b -99







:DONE
	!bat_popecho! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	!bat_echolog! Done with %0 %*
	!bat_echolog!
	
exit /b !bat_returncode!


