
@echo off
setlocal enableextensions enabledelayedexpansion
	Rem ===========================================================================================
	Rem   New Zealand sites batch file
	Rem ===========================================================================================


	rem ----------------------------------------------
	rem The :SETUP section sets up initial variables, reads the INI file,
	rem sets the log file variables, and displays the header.
:SETUP
	rem trigger the delayed expansion functionality
	for /f %%a in ("%~0") do (echo %%a)
	
	rem Variable to be able to use %bat_return% to return from subroutines.
	set bat_return=goto :EOF

	rem bat_exedir variable is where the rundir should be.
	set bat_exedir=%~dp0::
	set bat_exedir=!bat_exedir:\::=!
	set bat_exedir=!bat_exedir:::=!

	Rem ===========================================================================================
	Rem   Update (append to) the daily log file
	Rem ===========================================================================================

	Rem ===========================================================================================
	Rem   Set some run parameters for processing (no spaces around equal sign)
	Rem
	Rem      First camera number of a 16 camera set with sequential/inclusive numbering
	Rem      Number of independent detection processes to run during capture
	Rem      Start and stop time is based on sun elevation angle below local horizon
	Rem      Number of FF files to skip for any given camera when doing star extraction
	Rem      Number of stars to extract from each FF file
	Rem      Number of CapturedFiles subfolders to retain before purging (deleting for space)
	Rem      The CAMS directory full pathname up to and WITHOUT the \CAMS appended to the end
	Rem
	Rem ===========================================================================================

	rem "ReadParams_capture16.bat" reads the "capture16.params.ini" file to
	rem get all the variables for the parameters.  
	echo.call "!bat_exedir!\ReadParams_capture16.bat"
	     call "!bat_exedir!\ReadParams_capture16.bat"

	rem bat_LogFile is the target file for logging
	set bat_LogFile=!bat_CAMS_distrofolder!\DailyRunLog_!bat_firstcamera!.txt
	set bat_batchfile=%~nx0&	rem bat_batchfile is used for identifying which subroutine in the logs

	rem Indicate the start of the script 
	echo. bat_LogFile=!bat_LogFile!
	echo.>>"!bat_LogFile!"
	echo.>>"!bat_LogFile!"
    echo.[!date:~4! !time!]  ---------------------------------------------------------------
    echo.[!date:~4! !time!]  --------------------------------------------------------------->>"!bat_LogFile!"
	echo.[!date:~4! !time!]  %~nx0 %*
	echo.[!date:~4! !time!]  %~nx0 %*>>"!bat_LogFile!"

	rem See :SIM_DELETE for description of simulation
	rem Only perform the simulation deletion subroutine if simulation is enabled
	if /i "!bat_SIMULATION.simulate!" equ "true" (
		call :SIM_DELETE
	)

	goto :MAIN %*


	rem ------------------------------------------------------
	rem :MAIN 
	rem This is the main section of code for the rest of the script.  It calls 
	rem all the other subroutines.
	rem ------------------------------------------------------
:MAIN
	call :DEL_OLDCAPTURE %*
	call :PRECAPTURE %*
	call :LAUNCHCAPTURE %*

	call :GETCAPTURESESSION %*
	if /i "!bat_returncode!" neq "0" (
		goto :MAIN_END
	)


	call :COMBINE_DETECT %*
	if !errorlevel! neq 0 (
		goto :MAIN_END
	)


	call :STAR_EXTRACT %*
	if !errorlevel! neq 0 (
		goto :MAIN_END
	)


	call :ZIP %*
	if !errorlevel! neq 0 (
		goto :MAIN_END
	)
	
	call :FTP %*
	if !errorlevel! neq 0 (
		rem The return code from this is compound. The thousands digits are the 
		rem return code from the first transfer and the ones digits are the return
		rem code from the second transfer. 
		rem It doesn't matter at this point which one fails unless there is 
		rem something else to add after this section.
		goto :MAIN_END
	)

:MAIN_END
goto :DONE



	Rem ===========================================================================================
	Rem   Identify older CapturedFiles folders by sorting in reverse name order
	Rem   Delete the oldest CaptureFiles folders if there are more than the subfolder limit
	Rem ===========================================================================================
:DEL_OLDCAPTURE
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.DEL_OLDCAPTURE] %*>>"!bat_LogFile!"

	set bat_subfolder_count=0

	for /f "usebackq tokens=*" %%a in (`dir "!bat_CAMS_capturefolder!\20??_*" /ad /b /o-n`) do (

		set bat_subfolder_oldcapture=%%~na

		set /a bat_subfolder_count+=1

		if !bat_subfolder_count! GTR !bat_captured_folder_limit!  (
			echo.[!Date:~4! !Time!]    ---- Deleting folder "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!">>"!bat_LogFile!"
		                      echo.    ---- Deleting folder "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!"

			echo.[!Date:~4! !Time!]    del /q "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!">>"!bat_LogFile!"
			                           del /q "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!"

			echo.[!Date:~4! !Time!]    rmdir /q "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!">>"!bat_LogFile!"
			                           rmdir /q "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!"

			if not exist "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!" (
				echo.[!Date:~4! !Time!]    CapturedFiles folder !bat_subfolder_oldcapture! deleted >>"!bat_LogFile!"
				set bat_returncode=0
			) else (
				echo.[!Date:~4! !Time!]    ERROR - FAILED TO REMOVE FOLDER: "!bat_CAMS_capturefolder!\!bat_subfolder_oldcapture!">>"!bat_LogFile!"
				set bat_returncode=1
			)
		)
	)

:DEL_OLDCAPTURE_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.DEL_OLDCAPTURE] [bat_returncode=!bat_returncode!, bat_subfolder_count=!bat_subfolder_count!, bat_subfolder_oldcapture=!bat_subfolder_oldcapture!]>>"!bat_LogFile!"
exit /b !bat_returncode!



	Rem ===========================================================================================
	Rem   Identify most recently run CapturedFiles subfolder by sorting on folder name (date).
	Rem ===========================================================================================
:PRECAPTURE
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.PRECAPTURE] %*>>"!bat_LogFile!"
	set bat_returncode=0

	set bat_subfolder_precapture=2000_01_01_00_00_00


	for /f "usebackq tokens=*" %%a in (`dir "!bat_CAMS_capturefolder!\20??_*" /ad /b /on`) do (

		set bat_subfolder_precapture=%%~na
	)
	
	if /i "!bat_subfolder_precapture!" equ "2000_01_01_00_00_00" (
		echo.[!Date:~4! !Time!]    No previous directories in the CapturedFiles directory. >>"!bat_LogFile!"
	)

:PRECAPTURE_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.PRECAPTURE] [!bat_subfolder_precapture!]>>"!bat_LogFile!"
exit /b !bat_returncode!


	Rem ===========================================================================================
	Rem   Launch the real-time 16-channel capture and detection code
	Rem
	Rem   args = 1st camera, #detect proceses, sun angle below horizon for capture start, directory 
	Rem ===========================================================================================
:LAUNCHCAPTURE 
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.LAUNCHCAPTURE] %*>>"!bat_LogFile!"

	if /i "!bat_SIMULATION.simulate!" equ "true" (
		call :SIM_CAPTURE
		set bat_returncode=0
		goto :LAUNCHCAPTURE_END
	)

	echo.[!Date:~4! !Time!]    Starting FTP_Capture16AndDetect >>"!bat_LogFile!"

	CALL  "!bat_CAMS_runfolder!\FTP_Capture16AndDetect.exe"  !bat_firstcamera!  !bat_numdetectproc!  !bat_sun_elevation_deg!  "!bat_CAMS_directory!"
	set bat_returncode=!errorlevel!

	echo.[!Date:~4! !Time!]    Finished FTP_Capture16AndDetect with bat_returncode=[!bat_returncode!] >>"!bat_LogFile!"

:LAUNCHCAPTURE_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.LAUNCHCAPTURE] [bat_returncode=!bat_returncode!]>>"!bat_LogFile!"
exit /b !bat_returncode!


	Rem ===========================================================================================
	Rem   Identify newly generated CapturedFiles subfolder by sorting on folder name (date).
	Rem ===========================================================================================
:GETCAPTURESESSION
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.GETCAPTURESESSION] %*>>"!bat_LogFile!"

	set bat_returncode=1
	set bat_capturesession=2000_01_01_00_00_00

	for /f "usebackq tokens=*" %%a in (`dir "!bat_CAMS_capturefolder!\20??_*" /ad /b /on`) do (

		set bat_capturesession=%%~na
		set bat_returncode=0
	)

	if "!bat_returncode!" neq "0" (
		echo.[!Date:~4! !Time!]    ERROR - No new Capture Session>>"!bat_LogFile!"
	)
:GETCAPTURESESSION_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.GETCAPTURESESSION] [bat_returncode=!bat_returncode!, bat_capturesession=!bat_CAMS_capturefolder!\!bat_capturesession!]>>"!bat_LogFile!"
exit /b !bat_returncode!



	Rem ===========================================================================================
	Rem   If a new subfolder of imagery created then
	Rem
	Rem      Create new subfolder under the distro folder for the given night
	Rem
	Rem      Combine detectinfo files creating FTPdetectinfo_0000_YYYY_MM_DD_HH_MM_SS.txt
	Rem
	Rem      Rename merged detectinfo to 0!bat_firstcamera!...cam# [such as 0701] so other sites can be combined (merged)
	Rem 
	Rem      Run star extractor( #FF files to step over, #stars to extract, FF file directory )
	Rem
	Rem      Copy detectinfo and star files to new subfolder in the distro folder
	Rem
	Rem      Zip the latest detectinfo and star files and place in distro folder
	Rem 
	Rem ===========================================================================================
:COMBINE_DETECT
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.COMBINE_DETECT] %*>>"!bat_LogFile!"

	set bat_returncode=0

	if /i "!bat_subfolder_precapture!" NEQ "!bat_capturesession!"  (

		mkdir "!bat_CAMS_distrofolder!\!bat_capturesession!"

		echo.[!Date:~4! !Time!]    New CapturedFiles folder !bat_CAMS_capturefolder!\!bat_capturesession! >>"!bat_LogFile!"

		echo.[!Date:~4! !Time!]    Starting Detectinfo Combine... >>"!bat_LogFile!"


		echo.[!Date:~4! !Time!]    CALL  "!bat_CAMS_runfolder!\FTP_CombineDetectinfo.exe"  "!bat_CAMS_capturefolder!\!bat_capturesession!">>"!bat_LogFile!"
		                           CALL  "!bat_CAMS_runfolder!\FTP_CombineDetectinfo.exe"  "!bat_CAMS_capturefolder!\!bat_capturesession!"
		set bat_returncode=!errorlevel!
		echo.[!Date:~4! !Time!]    Finished Detectinfo Combine [bat_returncode=!bat_returncode!]>>"!bat_LogFile!"

		echo.[!Date:~4! !Time!]    copy /y "!bat_CAMS_capturefolder!\!bat_capturesession!\FTPdetectinfo_0000_*.txt"  "!bat_CAMS_capturefolder!\!bat_capturesession!\FTPdetectinfo_0!bat_firstcamera!_*.txt">>"!bat_LogFile!"
		                           copy /y "!bat_CAMS_capturefolder!\!bat_capturesession!\FTPdetectinfo_0000_*.txt"  "!bat_CAMS_capturefolder!\!bat_capturesession!\FTPdetectinfo_0!bat_firstcamera!_*.txt"

		set bat_detectinfo_filename=
		for /f "usebackq tokens=*" %%a in (`dir "!bat_CAMS_capturefolder!\!bat_capturesession!\FTPdetectinfo_0!bat_firstcamera!_*.txt" /a-d /b /on`) do (

			set bat_detectinfo_filename=%%~na

			echo.[!Date:~4! !Time!]    copy /y "!bat_CAMS_capturefolder!\!bat_capturesession!\!bat_detectinfo_filename!.txt" "!bat_CAMS_distrofolder!\!bat_capturesession!\!bat_detectinfo_filename!_!bat_firstcamera!.txt">>"!bat_LogFile!"
			                           copy /y "!bat_CAMS_capturefolder!\!bat_capturesession!\!bat_detectinfo_filename!.txt" "!bat_CAMS_distrofolder!\!bat_capturesession!\!bat_detectinfo_filename!_!bat_firstcamera!.txt"

			if exist "!bat_CAMS_distrofolder!\!bat_capturesession!\!bat_detectinfo_filename!_!bat_firstcamera!.txt" (
				echo.[!Date:~4! !Time!]    SUCCESS - Detectinfo File Copied to Distro "!bat_CAMS_distrofolder!\!bat_capturesession!\!bat_detectinfo_filename!_!bat_firstcamera!.txt">>"!bat_LogFile!">>"!bat_LogFile!"
			) else (
				set bat_returncode=1
				echo.[!Date:~4! !Time!]    ###FAILED - Detectinfo File Copied to Distro "!bat_CAMS_distrofolder!\!bat_capturesession!\!bat_detectinfo_filename!_!bat_firstcamera!.txt">>"!bat_LogFile!">>"!bat_LogFile!"
			)
		)
		
		if not defined bat_detectinfo_filename (
			set bat_returncode=2
			echo.[!Date:~4! !Time!]    FAILED - Unable to perform loop: [for ... dir "!bat_CAMS_capturefolder!\!bat_capturesession!\FTPdetectinfo_0!bat_firstcamera!_*.txt" /a-d /b /on]>>"!bat_LogFile!"
		)

	) else (
		set bat_returncode=3
		echo.[!Date:~4! !Time!]    ###ERROR - No new CapturedFiles folder. Skipping post-capture processing ###ERROR>>"!bat_LogFile!"
	)

:COMBINE_DETECT2

:COMBINE_DETECT_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.COMBINE_DETECT] %*>>"!bat_LogFile!"
exit /b !bat_returncode!



	rem =======================================================================
	rem :STAR_EXTRACT
	rem This subroutine calls the FTP_CalStarExtractor.exe program and provides
	rem it the command line arguments specific to the session.
	rem =======================================================================
:STAR_EXTRACT
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.STAR_EXTRACT] %*>>"!bat_LogFile!"

	set bat_returncode=0
	
	echo.[!Date:~4! !Time!]    Starting Star Extractor >>"!bat_LogFile!"

	CALL  "!bat_CAMS_runfolder!\FTP_CalStarExtractor.exe"  !bat_nstep_FFfile!  !bat_nstars!  "!bat_CAMS_capturefolder!\!bat_capturesession!"
	set bat_returncode=!errorlevel!
		  
	if !bat_returncode! EQU 3  (
		rem FTP_CalStarExtractor.exe failed
		echo.[!Date:~4! !Time!]    ###ERROR Star Extractor failed to find dir list ###ERROR>>"!bat_LogFile!" 
		goto :STAR_EXTRACT_END
	)

	if !bat_returncode! EQU 4  (
		rem FTP_CalStarExtractor.exe failed
		echo.[!Date:~4! !Time!]    ###ERROR Star Extractor found no FF files       ###ERROR>>"!bat_LogFile!" 
		goto :STAR_EXTRACT_END
	)

	if !bat_returncode! EQU 0  (
		rem If the FTP_CalStarExtractor.exe program succeeded

		echo.[!Date:~4! !Time!]    Finished Star Extractor >>"!bat_LogFile!"

		rem Copy the matching "CALSTARS*.txt" from the CapturedFiles dir to the 
		rem DistroFiles folder.
		set bat_star_filename=
		for /f "usebackq tokens=*" %%a in (`dir "!bat_CAMS_capturefolder!\!bat_capturesession!\CALSTARS*.txt" /a-d /b /on`) do (

			set bat_star_filename=%%~na

			copy /y "!bat_CAMS_capturefolder!\!bat_capturesession!\!bat_star_filename!.txt" "!bat_CAMS_distrofolder!\!bat_capturesession!"
		)

		if not defined bat_star_filename (
			rem You get here if the for loop didn't start because the dir command in the 
			rem parenthesis failed.
			echo.[!Date:~4! !Time!]    FAILED to loop [for... dir "!bat_CAMS_capturefolder!\!bat_capturesession!\CALSTARS*.txt" /a-d /b /on]>>"!bat_LogFile!"
			goto :STAR_EXTRACT_END
		)

		echo.[!Date:~4! !Time!]    Star Files Copied to Distro >>"!bat_LogFile!"

	) else (
		set bat_returncode=99
		echo.[!Date:~4! !Time!]    ###ERROR Star Extractor had some undefined error       ###ERROR>>"!bat_LogFile!" 
		goto :STAR_EXTRACT_END
	)

:STAR_EXTRACT2

:STAR_EXTRACT_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.STAR_EXTRACT] %*>>"!bat_LogFile!"
exit /b !bat_returncode!



	rem =================================================================
	rem :ZIP
	rem This subroutine zips the results in preparation for transport. 
	rem
	rem The bat_zipfile variable contains the full path of the zip file.
	rem The bat_zip variable contains just the filename without the path.
	rem
	rem This routine calls 
	rem =================================================================
:ZIP
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.ZIP] %*>>"!bat_LogFile!"
	set bat_returncode=0
	
	echo.[!Date:~4! !Time!]    Starting 7-zip of txt files >>"!bat_LogFile!"
	set bat_zipfile=!bat_CAMS_distrofolder!\!bat_capturesession!_!bat_firstcamera!.zip
	set bat_zip=!bat_capturesession!_!bat_firstcamera!.zip

	rem Call the 7za.exe tool to create the zip file. 
	echo.[!Date:~4! !Time!]    call "!bat_CAMS_runfolder!\7za.exe"  a  -tzip  "!bat_CAMS_distrofolder!\!bat_capturesession!_!bat_firstcamera!.zip" "!bat_CAMS_distrofolder!\!bat_capturesession!\*.txt">>"!bat_LogFile!
	                           call "!bat_CAMS_runfolder!\7za.exe"  a  -tzip  "!bat_CAMS_distrofolder!\!bat_capturesession!_!bat_firstcamera!.zip" "!bat_CAMS_distrofolder!\!bat_capturesession!\*.txt"
	set bat_returncode=!errorlevel!

	echo.[!Date:~4! !Time!]    Finished 7-zip of txt files >>"!bat_LogFile!"

:ZIP_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.ZIP] [bat_returncode=!bat_returncode!]>>"!bat_LogFile!"
exit /b !bat_returncode!



	rem =======================================================================
	rem :FTP
	rem This subroutine calls the ftp transfer routine
	rem
	rem It calls it twice.  Once, with the standard variables from the [FTP] section
	rem of the INI file:  
	rem   [FTP]
	rem   bat_ftppassword=pjenniskens@seti.org
	rem   bat_ftpsite=ftp.seti.org
	rem   bat_ftpuser=anonymous
	rem   bat_ftpdir=incoming/cams
	rem   transfer_script=ftp_transfer_seti.bat
	rem
	rem The second time uses the variables from the [FTP2] section.
	rem   [FTP2]
	rem   ftppassword=
	rem   ftpsite=ftp.davesamuels.com
	rem   ftpuser=davesamu
	rem   ftpdir=web/junk/testftp
	rem   transfer_script=ftp_transfer_seti.bat
	rem
	rem The "transfer_script" variable allows the user to specify a custom script
	rem to use for transfer in case the standard transfer won't do the job. 
	rem It is possible that if a custom script is required, it's okay to add
	rem any variables to the FTP2 section that would be required to support the
	rem transfer, even if a protocol other than FTP is used.
	rem The bat_returncode is a compound return code.  The thousands digits
	rem are the return code from the first transfer and the ones digits
	rem are the return code from the second transfer.
	rem =======================================================================
:FTP
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.FTP] %*>>"!bat_LogFile!"
	set bat_returncode=0

	call "!bat_CAMS_runfolder!\!bat_FTP.transfer_script!" "!bat_zipfile!" "!bat_zip!"
	set /a bat_returncode=!errorlevel!*1000
	rem Save the original variables... kind of like PUSHing them on the stack 
	SETLOCAL enableextensions enabledelayedexpansion
	
		rem Copy the FTP2 variables to the standard variables
		set bat_ftppassword=!bat_FTP2.ftppassword!
		set bat_ftpsite=!bat_FTP2.ftpsite!
		set bat_ftpuser=!bat_FTP2.ftpuser!
		set bat_ftpdir=!bat_FTP2.ftpdir!

		rem Now call the transfer routine a second time.  If 
		call "!bat_CAMS_runfolder!\!bat_FTP2.transfer_script!" "!bat_zipfile!" "!bat_zip!"
		set /a bat_returncode += !errorlevel!
	rem POP the original FTP parameters
	ENDLOCAL

:FTP_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.FTP] [bat_returncode=!bat_returncode!]>>"!bat_LogFile!"
exit /b !bat_returncode!






	rem ---------------------------------------------------------
	rem If simulation is enabled, the first thing to do is to remove the existing
	rem capture directory.  
	rem Simulation is enabled by setting the "simulate=" flag in the [SIMULATION] 
	rem section of the INI file to "true".  For example:
	rem    [SIMULATION]
	rem    simulate=true
	rem    sim_session=2013_10_30_06_21_56
	rem    sim_sourcedir=!bat_CAMS_directory!\Simulation\CapturedFiles\2013_10_30_06_21_56
	rem 
	rem The "sim_session" variable is the session date/time stamp [The CapturedFiles
	rem folder name].
	rem
	rem The "sim_sourcedir" variable is the full path for the :SIM_CAPTURE subroutine
	rem to copy from.  
	rem
	rem This :SIM_DELETE performs the function of clearing out the session's
	rem files in order to start fresh.  The :SIM_CAPTURE subroutine will be 
	rem called from within the :LAUNCHCAPTURE subroutine only if "simulate=true".
	rem ---------------------------------------------------------
:SIM_DELETE
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.SIM_CAPTURE] %*>>"!bat_LogFile!"
	rem set bat_SIMULATION.

	echo.[!Date:~4! !Time!]  DEL /Q /s "!bat_CAMS_capturefolder!\!bat_SIMULATION.sim_session!"
	                         DEL /Q /s "!bat_CAMS_capturefolder!\!bat_SIMULATION.sim_session!"
	echo.[!Date:~4! !Time!]  RD /Q /s "!bat_CAMS_capturefolder!\!bat_SIMULATION.sim_session!"
	                         RD /Q /s "!bat_CAMS_capturefolder!\!bat_SIMULATION.sim_session!"
	echo.[!Date:~4! !Time!]  DEL /Q /s "!bat_CAMS_distrofolder!\!bat_SIMULATION.sim_session!"
	                         DEL /Q /s "!bat_CAMS_distrofolder!\!bat_SIMULATION.sim_session!"
	echo.[!Date:~4! !Time!]  RD /Q /s "!bat_CAMS_distrofolder!\!bat_SIMULATION.sim_session!"
	                         RD /Q /s "!bat_CAMS_distrofolder!\!bat_SIMULATION.sim_session!"
	echo.[!Date:~4! !Time!]  DEL /Q "!bat_CAMS_distrofolder!\!bat_SIMULATION.sim_session!_!bat_firstcamera!.zip"
	                         DEL /Q "!bat_CAMS_distrofolder!\!bat_SIMULATION.sim_session!_!bat_firstcamera!.zip"
							   
	set bat_returncode=0

:SIM_DELETE_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.SIM_DELETE] [bat_returncode=!bat_returncode!]>>"!bat_LogFile!"
exit /b !bat_returncode!



	rem ----------------------------------------------------------
	rem :SIM_CAPTURE 
	rem Called from within the :LAUNCHCAPTURE subroutine.  It copies the files
	rem from directory specified in the "bat_SIMULATION.sim_sourcedir" variable.
	rem 
	rem Just in case the computer is set to the en_NZ locale, the date is parsed
	rem accordingly.  Otherwise, the en_US locale date parsing is used.
	rem 
	rem    [SIMULATION]
	rem    simulate=true
	rem    sim_session=2013_10_30_06_21_56
	rem    sim_sourcedir=!bat_CAMS_directory!\Simulation\CapturedFiles\2013_10_30_06_21_56
	rem
	rem The date parsing is necessary for 
	rem ----------------------------------------------------------
:SIM_CAPTURE
echo.[!Date:~4! !Time!]  [CALL :!bat_batchfile!.SIM_CAPTURE] %*>>"!bat_LogFile!"

	rem Parse date for default locale [en_US]
	rem The bat_date variable is set to the 10/30/2013 format
	rem The bat_time variable is set to the 06:21:56.00 format.  Since we don't
	rem really have the fractions of second, we'll use zero, since it probably won't matter.
	set bat_date=!bat_SIMULATION.sim_session:~5,2!/!bat_SIMULATION.sim_session:~8,2!/!bat_SIMULATION.sim_session:~0,4!
	set bat_time=!bat_SIMULATION.sim_session:~11,2!:!bat_SIMULATION.sim_session:~14,2!:!bat_SIMULATION.sim_session:~17,2!.00
	set bat_yyyy=!bat_date:~6,4!
	set bat_mm=!bat_date:~0,2!
	set bat_dd=!bat_date:~3,2!
	set bat_hh=!bat_time:~0,2!
	set bat_min=!bat_time:~3,2!
	set bat_sec=!bat_time:~6,2!
	
	rem Pad the bat_msec to exactly 3 digits
	set bat_msec=000!bat_time:~-2!0
	set bat_msec=!bat_msec:~-3!
	
	
	REM Process for en-NZ locale
	if /i "!bat_locale!" equ "en-NZ" (
		set bat_mm=!bat_date:~3,2!
		set bat_dd=!bat_date:~0,2!
	)

	rem Set variables compatible with CAMS
	rem Note: the bat_captureddatetime variable should have the same value as
	rem       bat_SIMULATION.sim_session
	set bat_captureddate=!bat_yyyy!_!bat_mm!_!bat_dd!
	set bat_capturedtime=!bat_hh!_!bat_min!_!bat_sec!
	set bat_captureddatetime=!bat_captureddate!_!bat_capturedtime!
	
	rem Make the target directory
    echo.[!date:~4! !time!]    md "!bat_CAMS_capturefolder!\!bat_SIMULATION.sim_session!">>"!bat_LogFile!"
                               md "!bat_CAMS_capturefolder!\!!bat_SIMULATION.sim_session!"
							   
	rem Copy the simulation source files to the target dir
    echo.[!date:~4! !time!]    copy /y "!bat_CAMS_directory!\Simulation\CapturedFiles\!bat_captureddatetime!" "!bat_CAMS_capturefolder!\!bat_captureddatetime!">>"!bat_LogFile!"
                               copy /y "!bat_CAMS_directory!\Simulation\CapturedFiles\!bat_captureddatetime!" "!bat_CAMS_capturefolder!\!bat_captureddatetime!"
							   
	set bat_returncode=0

:SIM_CAPTURE_END
echo.[!Date:~4! !Time!]  [RETURN :!bat_batchfile!.SIM_CAPTURE] [bat_returncode=!bat_returncode!]>>"!bat_LogFile!"
exit /b !bat_returncode!





Rem ===========================================================================================
Rem   End of batch program
Rem ===========================================================================================
:DONE
rem List the final state of all the variables
rem SET BAT_
	echo.
	echo.[!date:~4! !time!] [DONE] bat_returncode=[!bat_returncode!]>>"!bat_LogFile!"
	echo.[!date:~4! !time!]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~>>"!bat_LogFile!"
	echo.>>"!bat_LogFile!"
	echo.[!date:~4! !time!] [DONE] bat_returncode=[!bat_returncode!]
	echo.[!date:~4! !time!]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	echo.
rem Set the return code so a calling program or script can get the errorlevel or return code. This is the same as the return code from main() in a C program.
exit /b !bat_returncode!



