@echo off
setlocal enableextensions enabledelayedexpansion

:CHECKHELP
    echo.%*|find /i "/?">nul:
    if %errorlevel% equ 0 goto :HELP
    echo.%*|find /i "/h">nul:
    if %errorlevel% equ 0 goto :HELP
    echo.%*|find /i "/help">nul:
    if %errorlevel% equ 0 goto :HELP

:SETUP
	if "%~1" equ "" goto :HELP
	
	call "%~dp0AutoCams.setup.bat" "%~dpnx0"
	call "%~dp0indent_setup.bat"

	!bat_log! =============================================================
	!bat_log! %date% %time% - Version: !bat_vers! - %~0 [%*]
	!bat_log!

        rem This routine parses out the elements of a directory or full file name
        rem and path and returns the last segment (either the filename or the last
        rem directory name) as well as the parent path. It removes the trailing 
        rem backslash from everything also.  It is designed to be called several
        rem times as needed (where you'd pass !bat_retval1! as the argument in
        rem subsequent calls) to further parse everything out. 
        rem
        rem This example will explain the two output variables:
        rem    arg1=c:\cams\archivedfiles\2012_02_07_02_43_36\
        rem    bat_retval1=c:\cams\archivedfiles
        rem    bat_retval2=2012_02_07_02_43_36
        rem
:PARSEDIR [in] c:\cams\archivedfiles\2012_02_07_02_43_36\ [out] c:\cams\archivedfiles 
!bat_pushlog! [CALL !bat_batchfile!:PARSEDIR] [in] %*
        !bat_log! [in "%~1"]
        !bat_log! [out should be "%~dp1"
        !bat_log! [out should be "%~nx1"
        
        
        rem If it's called without the return variables to populate, then use bat_retval1 as the return val
        if "%~2" equ "" (
        	set bat_out1=bat_retval1
        ) else (
			set bat_out1=%~2
        )

        rem If it's called without the return variables to populate, then use bat_retval1 as the return val
		if "%~3" equ "" (
        	set bat_out2=bat_retval2
		) else (
			set bat_out2=%~3
		)
 
 		rem 
        set bat_retval=
        set bat_retval1=
        set bat_retval2=
        
        rem If the entire directory is pointing to the root drive letter of
        rem a dir, there is nothing to parse. The bat_retval1 and bat_retval2
        rem variables will be undefined.  
        if /i "%~1" equ "!bat_targetdrive!" goto :PARSEDIR_END

        !bat_logexeclog! set bat_retval1=%~dp1::
        !bat_logexeclog! set bat_retval1=!bat_retval1:\::=!
        !bat_logexeclog! set bat_retval1=!bat_retval1:::=!

        !bat_logexeclog! set bat_retval2=%~nx1

        !bat_log! [out=!bat_out1!] "!bat_retval1!"
        !bat_log! [out=!bat_out2!] "!bat_retval2!"


:PARSEDIR_END
!bat_poplog! [RETURN !bat_batchfile!:PARSEDIR] [!bat_out1!=!bat_retval1!, !bat_out2!=!bat_retval2!]
!bat_log! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!bat_log! [!bat_batchfile!:ENDLOCAL set retval1=%bat_retval1%, set retval2=%bat_retval2%]
!bat_log!
	( ENDLOCAL & REM RETURN VALUES
	    SET %bat_out1%=%bat_retval1%
	    SET %bat_out2%=%bat_retval2%
	    SET bat_retval1=%bat_retval1%
	    SET bat_retval2=%bat_retval2%
	    
	)

exit /b 0


:HELP
	echo %~nx0
	echo.
	echo Usage: %~n0 "path" ["basepath"] ["dirname"]
	echo.
	echo. This routine parses out the elements of a directory or full file name
	echo. and path and returns the last segment (either the filename or the last
	echo. directory name) as well as the parent path. It removes the trailing 
	echo. backslash from everything also.  It is designed to be called several
	echo. times as needed (where you'd pass %%bat_retval1%% as the argument in
	echo. subsequent calls) to further parse everything out. 
	echo.
	echo. Where:
	echo.    basepath       - optional.  If omitted, then the basepath is returned in bat_retval1.
	echo.    dirname        - optional.  If omitted, then the dir/file name is returned in bat_retval2
	echo.
	echo. Returns:
	echo.    bat_retval1    - Returns the parent dir without the trailing backslash [~dpX]
	echo.                     Given C:\dir1\dir2\dir3\name.ext, returns C:\dir1\dir2\dir3
	echo.                     Given C:\dir1\dir2\dir3,          returns C:\dir1\dir2
	echo.    bat_retval2    - Returns the filename component without the path [~nxX]
	echo.                     Given C:\dir1\dir2\dir3\name.ext, returns name.ext
	echo.                     Given C:\dir1\dir2\dir3,          returns dir3
	echo.
	echo. This example will explain the two output variables:
	echo.    arg1=c:\cams\archivedfiles\2012_02_07_02_43_36\
	echo.    bat_retval1=c:\cams\archivedfiles
	echo.    bat_retval2=2012_02_07_02_43_36
	echo.
	echo. This example parses 
	echo.   call "!bat_exedir!\ParseDir.bat" "c:\cams\archivedfiles\2012_02_07_02_43_36\" "bat_basedir" "bat_basedir_name" 
	echo.
	echo Where:
	echo       path         - The full path that you want to parse. 
	echo                      [For example C:\CAMS\ArchivedFiles\2012_08_11_02_43_55\
	echo       basepath     - The result of stripping off the last dir/file name
	echo                      from the path [for example C:\CAMS\ArchivedFiles]
	echo       dirname      - The last dir/file name from the given path
	echo                      [for example 2012_08_11_02_43_55]
	echo.
	echo Note: It works with or without the trailing backslash.
	echo.
	echo.Example in use:
	echo.  	call "!bat_exedir!\ParseDir.bat" "C:\CAMS\ArchivedFiles\2012_08_11_02_43_55\" "bat_basedir" "bat_basedir_name" 
	echo.Results:
	echo.   bat_basepath=
	echo.  	call "!bat_exedir!\ParseDir.bat" "!bat_basedir!" "bat_basedir" "bat_basedir_name" 
	echo.
exit /b -99



