  @echo off
setlocal ENABLEEXTENSIONS ENABLEDELAYEDEXPANSION

rem StrLen.bat
rem
rem Usage: strlen "This is the test string" "test" [return variable name]
rem
rem Returns: 
rem     -1      if not found
rem      n      length of string
rem

:CHECKHELP

	(echo.%*|findstr /L /i /c:"/help" /c:"/h" /c:"/?" >nul: 2>&1) && (goto :HELP)

:CHECKHELP_END
goto :SETUP %*


:SETUP
	set /a bat_position=0

	if /i "%~1" EQU "/v" (
		set bat_verbose=/i
		shift
	) else (
		set bat_verbose=
	)


	if "%~1" equ "" (exit /b -2)
	if "%~2" equ "" (exit /b -3)

	set bat_sourcestr=%~1
	set bat_searchstr=%~2
	set bat_retvar=%~3
	
goto :MAIN %*

:MAIN

		rem Note: When bat_searchstr begins with a "*", it will
		rem       match everything from the beginning of the 
		rem       expanded output to the first occurence of the 
		rem       remaining portion of bat_searchstr.
		rem
		rem Get everything to the right of the first occurence of
		rem the search string but not including the search string
		rem ----------------------- v
	set bat_rightstr=!bat_sourcestr:*%~2=!
	
rem	echo.bat_rightstr="!bat_rightstr!"


	if "!bat_rightstr!" equ "!bat_sourcestr!" (
		echo."!bat_searchstr!" Not Found in "!bat_sourcestr!".>&2
		exit /b -1
	)
	
		rem Get the text to the left of the first occurance of the search string
	set bat_leftstr=!bat_sourcestr:%bat_searchstr%%bat_rightstr%=!
	
rem	echo.bat_leftstr="!bat_leftstr!"
	
	if "!bat_leftstr!" NEQ "" (
		for /L %%a in (0,1,8192) do (
			if "!bat_leftstr:~%%a,1!" NEQ "" (
				set /a bat_position+=1
			)
		)
	)
	
	if defined bat_verbose (
		echo.
		echo.The position of "!bat_searchstr!" in "!bat_sourcestr!" is: !bat_position!. 
		echo.
		echo.The string to the right of "!bat_searchstr!" is "!bat_rightstr!".
		echo.The string to the left of  "!bat_searchstr!" is "!bat_leftstr!"
		echo.
		if defined bat_retvar (
			echo.%bat_retvar%=%bat_position%
		)
	)

(ENDLOCAL & (
	if "%~3" neq "" (
		set %bat_retvar%=%bat_position%
	)
  )
  exit /b %bat_position%
)

GOTO :DONE



:HELP
	echo.StrPos.bat
	echo.
	echo.Usage: call "StrPos.bat" [/v] "^<source string^>" "^<search string^>" [return variable name]
	echo.
	echo.Finds the position of the ^<search string^> in the ^<source string^> where the first
	echo.character is position zero.
	echo.
	echo.Where:
	echo.     /v                Means verbose mode.  In verbose mode, it will display what
	echo.                       it found out in plain english.
	echo.
	echo.    source string      Is the text you're searching in.
	echo.
	echo.    search string      is the text that you looking for in the search string. 
	echo.
	echo.Returns:
	echo.    ERRORLEVEL         If it has a positive number greater than or equal to zero
	echo.                       then the position is that number.  If the ERRORLEVEL
	echo.                       is negative, then that indicates an error:
	echo.
	echo.      -1               Not Found
	echo.      -99              HELP was invoked and the script didn't run. 
	echo.
	echo.Example:
	echo.    call "StrPos.bat" /v "This is the test string" "test" "bat_retval"]
	echo.
	echo.    Results in %%ERRORLEVEL%% having a value of 10. 
	echo.
exit /b -99

:DONE
